==> antlr-java-parser-1.0.3-sources.jar: com/github/antlrjavaparser/adapter/ElementValueContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.expr.Expression;

public class ElementValueContextAdapter implements Adapter<Expression, Java7Parser.ElementValueContext> {
    public Expression adapt(Java7Parser.ElementValueContext context) {

        if (context.conditionalExpression() != null) {
            return Adapters.getConditionalExpressionContextAdapter().adapt(context.conditionalExpression());
        } else if (context.annotation() != null) {
            return Adapters.getAnnotationContextAdapter().adapt(context.annotation());
        } else if (context.elementValueArrayInitializer() != null) {
            return Adapters.getElementValueArrayInitializerContextAdapter().adapt(context.elementValueArrayInitializer());
        }

        throw new RuntimeException("Unknown Element Value type");
    }
}

==> antlr-java-parser-1.0.11-sources.jar: com/github/antlrjavaparser/adapter/ElementValueContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.expr.Expression;

public class ElementValueContextAdapter implements Adapter<Expression, Java7Parser.ElementValueContext> {
    public Expression adapt(Java7Parser.ElementValueContext context, AdapterParameters adapterParameters) {

        if (context.conditionalExpression() != null) {
            return Adapters.getConditionalExpressionContextAdapter().adapt(context.conditionalExpression(), adapterParameters);
        } else if (context.annotation() != null) {
            return Adapters.getAnnotationContextAdapter().adapt(context.annotation(), adapterParameters);
        } else if (context.elementValueArrayInitializer() != null) {
            return Adapters.getElementValueArrayInitializerContextAdapter().adapt(context.elementValueArrayInitializer(), adapterParameters);
        }

        throw new RuntimeException("Unknown Element Value type");
    }
}
